@@ -69,7 +69,7 @@ use strict;
 use base qw(Exporter);
 our @EXPORT_OK = qw( title );
 
-our $VERSION = '1.82';
+our $VERSION = '1.85';
 
 use Module::Pluggable (search_path => ['URI::Title'], require => 1 );
 use File::Type;
@@ -89,7 +89,7 @@ sub ua {
 
 sub get_limited {
   my $url = shift;
-  my $size = shift || 16*1024;
+  my $size = shift || 32*1024;
   my $ua = ua();
   $ua->max_size($size);
   my $req = HTTP::Request->new(GET => $url);
@@ -102,16 +102,17 @@ sub get_limited {
   # get an odd 4xx response that isn't 404, just try getting
   # the full thing. This may be a little impolite.
   return get_all($url) if $res->code >= 400 and $res->code < 500 and $res->code != 404;
-
   return unless $res->is_success;
-  return $res->decoded_content unless wantarray;
+  if (!wantarray) {
+    return $res->decoded_content || $res->content;
+  }
   my $cset = "iso-8859-1"; # default;
   my $ct = $res->header("Content-type");
-  if ($ct =~ /charset=\"?([\w-]+)/i) {
+  if ($ct =~ /charset\s*=\>?\s*\"?([\w-]+)/i) {
     $cset = lc($1);
     #warn "Got charset $cset from URI headers\n";
   }
-  return ($res->decoded_content, $cset);
+  return ($res->decoded_content || $res->content, $cset);
 }
 
 sub get_end {
@@ -224,6 +225,11 @@ sub title {
         $data = 1; # we don't need it, fake it.
 
       } else {
+        # special case for spotify
+        $url =~ s{^(?:http://open.spotify.com/|spotify:)(\w+)[:/]}{http://spotify.url.fi/$1/};
+        
+        $url =~ s{#!}{?_escaped_fragment_=};
+
         ($data, $cset) = get_limited($url);
       }
     }
